@@ -11,10 +11,10 @@ use warnings;
 use English qw/ -no_match_vars /;
 use Path::Tiny;
 
-our $VERSION = 0.02;
+our $VERSION = 0.003;
 
 sub branch {
-    my ($self, $options) = @_;
+    my ($self) = @_;
     my ($type, $branch);
     my $dir = eval { path('.')->realpath };
     my $git = git();
@@ -90,7 +90,7 @@ App::PS1::Plugin::Branch - Adds the current branch to prompt
 
 =head1 VERSION
 
-This documentation refers to App::PS1::Plugin::Branch version 0.02.
+This documentation refers to App::PS1::Plugin::Branch version 0.003.
 
 =head1 SYNOPSIS
 
