@@ -13,24 +13,20 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use Path::Tiny;
 
-our $VERSION = 0.02;
+our $VERSION = 0.003;
 
 sub directory {
-    my ($self, $options) = @_;
+    my ($self) = @_;
 
     my $dir  = path('.')->absolute;
     my $home = path($ENV{HOME});
     my $dir_display = "$dir";
-    $options->{dir_length} ||= 30;
 
     if ($home->subsumes($dir) ) {
         $dir_display =~ s/$home/~/xms;
     }
-    if (length $dir_display > $options->{dir_length}) {
-        $dir_display = '...' . substr $dir_display, -$options->{dir_length}, $options->{dir_length};
-    }
-    if ($options->{abreviate}) {
-        $dir_display =~ s{/([^/])[^/]+/}{/$1/}g;
+    if (length $dir_display > 20) {
+        $dir_display = '...' . substr $dir_display, -20, 20;
     }
 
     my $len = length $dir_display;
@@ -58,32 +54,12 @@ sub directory {
         : $size >         10_000 ? sprintf "%dKiB"  , $size / 2**10
         : $size >            900 ? sprintf "%.1dKiB", $size / 2**10
         :                          $size;
-
-    my $dir_length  = 0;
-    my $file_length = 0;
-    my $size_length = 0;
-
-    if (!defined $options->{dir} || $options->{dir}) {
-        $dir_length = 6 + length $dir_count;
-        $dir_count  = $self->colour('dir_label') . " dir:"  . $self->colour('dir_size') . "$dir_count,";
-    }
-    else {
-        $dir_count = '';
-    }
-    if (!defined $options->{file} || $options->{file}) {
-        $file_length = 7 + length $file_count;
-        $file_count  = $self->colour('dir_label') . " file:" . $self->colour('dir_size') . "$file_count,";
-    }
-    else {
-        $file_count = '';
-    }
-    if (!defined $options->{size} || $options->{size}) {
-        $size_length = 1 + length $size;
-        $size        = $self->colour('dir_label') . " "      . $self->colour('dir_size') . $size;
-    }
-    else {
-        $size = '';
-    }
+    my $dir_length  = 6 + length $dir_count;
+    my $file_length = 7 + length $file_count;
+    my $size_length = 1 + length $size;
+    $dir_count  = $self->colour('dir_label') . " dir:"  . $self->colour('dir_size') . "$dir_count,";
+    $file_count = $self->colour('dir_label') . " file:" . $self->colour('dir_size') . "$file_count,";
+    $size       = $self->colour('dir_label') . " "      . $self->colour('dir_size') . $size;
 
     my $arb = @{$self->parts} + $self->parts_size;
     if ( $details[0] + $dir_length + $file_length + $size_length + $arb < $self->cols ) {
@@ -112,7 +88,7 @@ App::PS1::Plugin::Directory - Current directory information
 
 =head1 VERSION
 
-This documentation refers to App::PS1::Plugin::Directory version 0.02.
+This documentation refers to App::PS1::Plugin::Directory version 0.003.
 
 =head1 SYNOPSIS
 
