@@ -10,24 +10,23 @@ use strict;
 use warnings;
 use English qw/ -no_match_vars /;
 
-our $VERSION     = 0.002;
+our $VERSION     = 0.003;
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
-#our @EXPORT      = qw//;
 
 sub node {
     my ($self) = @_;
     my $version;
     my $path;
 
-    if ( $path = $ENV{NODE_PATH} ) {
-        # best guess for nave
-        ($version) = $path =~ /installed.(.*?).lib/;
-    }
-    elsif ( $path = $ENV{NVM_BIN} ) {
+    if ( $path = $ENV{NVM_BIN} ) {
         # best guess for nvm
         ($version) = $path =~ m{/([^/]+)/bin};
     }
+    elsif ( $path = $ENV{NODE_PATH} ) {
+        # best guess for nave
+        ($version) = $path =~ /installed.(.*?).lib/;
+    }
     else {
         return;
     }
@@ -47,7 +46,7 @@ App::PS1::Plugin::Node - Shows current version of node if using nave
 
 =head1 VERSION
 
-This documentation refers to App::PS1::Plugin::Node version 0.002.
+This documentation refers to App::PS1::Plugin::Node version 0.003.
 
 =head1 SYNOPSIS
 
